==> epoch-4.0b0.tar.gz: epoch-4.0b0/src/termhooks.h <==
/* Hooks by which low level terminal operations
   can be made to call other routines.
   Copyright (C) 1985, 1986 Free Software Foundation, Inc.

This file is part of GNU Emacs.

GNU Emacs is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 1, or (at your option)
any later version.

GNU Emacs is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Emacs; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */

/*
 * $Revision: 1.5 $
 * $Source: /import/kaplan/stable/distrib/epoch-4.0b0/src/RCS/termhooks.h,v $
 * $Date: 91/11/26 13:02:28 $
 * $Author: love $
 */

extern int (*move_cursor_hook) ();

extern int (*clear_window_end_hook) ();
extern int (*clear_to_end_hook) ();
extern int (*clear_screen_hook) ();

extern int (*update_line_hook) ();
extern int (*insert_chars_hook) ();
extern int (*delete_chars_hook) ();
extern int (*shift_region_hook) ();

extern int (*ring_bell_hook) ();

extern int (*reset_terminal_modes_hook) ();
extern int (*set_terminal_modes_hook) ();
extern int (*update_begin_hook) ();
extern int (*update_end_hook) ();
extern int (*set_terminal_window_hook) ();

extern int (*read_socket_hook) ();
extern int (*fix_screen_hook) ();
extern int (*calculate_costs_hook) ();

extern int (*text_width_hook) ();

/* If nonzero, send all terminal output characters to this stream also.  */

extern FILE *termscript;

==> epoch-4.2.tar.gz: epoch-4.2/src/termhooks.h <==
/* Hooks by which low level terminal operations
   can be made to call other routines.
   Copyright (C) 1985, 1986 Free Software Foundation, Inc.

This file is part of GNU Emacs.

GNU Emacs is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 1, or (at your option)
any later version.

GNU Emacs is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Emacs; see the file COPYING.  If not, write to
the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */

/*
 * $Revision: 1.5 $
 * $Source: /import/kaplan/stable/distrib/epoch-4.2/src/RCS/termhooks.h,v $
 * $Date: 91/11/26 13:02:28 $
 * $Author: love $
 */

extern int (*move_cursor_hook) ();

extern int (*clear_window_end_hook) ();
extern int (*clear_to_end_hook) ();
extern int (*clear_screen_hook) ();

extern int (*update_line_hook) ();
extern int (*insert_chars_hook) ();
extern int (*delete_chars_hook) ();
extern int (*shift_region_hook) ();

extern int (*ring_bell_hook) ();

extern int (*reset_terminal_modes_hook) ();
extern int (*set_terminal_modes_hook) ();
extern int (*update_begin_hook) ();
extern int (*update_end_hook) ();
extern int (*set_terminal_window_hook) ();

extern int (*read_socket_hook) ();
extern int (*fix_screen_hook) ();
extern int (*calculate_costs_hook) ();

extern int (*text_width_hook) ();

/* If nonzero, send all terminal output characters to this stream also.  */

extern FILE *termscript;
